@@ -5,7 +5,7 @@ import time
 import pymysql
 
 version = "0.4.1"
-version_info = (0, 4, 0, 0)
+version_info = (0, 4, 1, 0)
 
 
 class Connection(object):
@@ -21,7 +21,7 @@ class Connection(object):
         args = dict(
             host=host, use_unicode=use_unicode, charset=use_charset, user=user,
             database=database,
-            init_command=None,
+            init_command="",
             connect_timeout=connect_timeout, sql_mode="TRADITIONAL", passwd=password,
             autocommit=auto_commit, port=port,)
 
