@@ -20,8 +20,8 @@ except ImportError:
         raise
 
 
-version = "0.4.0"
-version_info = (0, 4, 0, 0)
+version = "0.4.1"
+version_info = (0, 4, 1, 0)
 
 class Connection(object):
     """A lightweight wrapper around MySQLdb DB-API connections.
@@ -47,7 +47,7 @@ class Connection(object):
         self.auto_commit = auto_commit
 
         args = dict(conv=CONVERSIONS, use_unicode=True, charset=use_charset,
-                    db=database, init_command=None,
+                    db=database, init_command="",
                     connect_timeout=connect_timeout, sql_mode="TRADITIONAL")
         if user is not None:
             args["user"] = user
